from logilab.mtconverter import xml_escape

from cubicweb.selectors import is_instance
from cubicweb.web import component


class InterestedInVComponent(component.Component):
    """section to control user intrested in a talk """
    __regid__ = 'interesting'
    __select__ = is_instance('Talk',)
    context = 'header'
    rtype = 'interested_in'
    target = 'object'
    htmlclass = 'mainRelated'
    cw_property_defs = {
        _('visible'):  dict(type='Boolean', default=True,
                            help=_('display the box or not')),
    }

    def call(self):
        user = self._cw.user
        _ = self._cw._
        eid = self.cw_rset[0][0]
        rset = self._cw.execute('Any X WHERE U interested_in X, U eid %(u)s, X eid %(x)s',
                                {'u': user.eid, 'x': eid})

        self.w(u'<div class="%s" id="%s">' % (self.__regid__, self.domid))
        if not rset.rowcount:
            # user isn't registered
            rql = 'SET U interested_in X WHERE U eid %(u)s, X eid %(x)s'
            title = _('click here if you are interested by this talk')
            msg = _('you are now registered for this talk')
        else:
            # user is registered
            rql = 'DELETE U interested_in X WHERE U eid %(u)s, X eid %(x)s'
            title = _('click here if you are not any more interested by this talk')
            msg = _('you are not anymore registered for this project')
        url = self._cw.user_rql_callback((rql, {'u': self._cw.user.eid, 'x': eid}),
                                         msg)
        self.w(u'<a href="%s">%s</a>' % (xml_escape(url), title))
        self.w(u'</div>')
        self.w(u'<div class="clear"></div>')



# pylint: disable-msg=W0622
"""cubicweb-skillmat application packaging information"""

modname = 'skillmat'
distname = 'cubicweb-skillmat'

numversion = (0, 8, 0)
version = '.'.join(str(num) for num in numversion)

license = 'LGPL'
description = 'skill matrix component for the CubicWeb framework'
author = 'Logilab'
author_email = 'contact@logilab.fr'
web = 'http://www.cubicweb.org/project/%s' % distname

__depends__ = {'cubicweb': '>= 3.10.0',
               'cubicweb-folder': None,
               'cubicweb-comment': None}

classifiers = [
    'Environment :: Web Environment',
    'Framework :: CubicWeb',
    'Programming Language :: Python',
    'Programming Language :: JavaScript',
    ]


# packaging ###

from os import listdir as _listdir
from os.path import join, isdir
from glob import glob

def listdir(dirpath):
    return [join(dirpath, fname) for fname in _listdir(dirpath)
            if fname[0] != '.' and not fname.endswith('.pyc')
            and not fname.endswith('~')]

CUBES_DIR = join('share', 'cubicweb', 'cubes')
THIS_CUBE_DIR = join(CUBES_DIR, modname)

try:
    data_files = [
        # common files
        [THIS_CUBE_DIR, [fname for fname in glob('*.py') if fname != 'setup.py']],
        ]
    # check for possible extended cube layout
    for dirname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18n', 'migration'):
        if isdir(dirname):
            data_files.append([join(THIS_CUBE_DIR, dirname), listdir(dirname)])
    # Note: here, you'll need to add subdirectories if you want
    # them to be included in the debian package
except OSError:
    # we are in an installed directory
    pass
